pub struct ArborServer { /* private fields */ }Expand description
The Arbor WebSocket server.
Implementations
Sourceimpl ArborServer
impl ArborServer
Sourcepub fn new(graph: ArborGraph, config: ServerConfig) -> Self
pub fn new(graph: ArborGraph, config: ServerConfig) -> Self
Creates a new server with the given graph.
Creates a new server with an existing shared graph handle.
Sourcepub fn graph(&self) -> Arc<RwLock<ArborGraph>>
pub fn graph(&self) -> Arc<RwLock<ArborGraph>>
Returns a handle to the shared graph for updates.